@@ -1,31 +1,13 @@
 package WWW::Curl;
 
 use strict;
-use warnings;
-use XSLoader;
+use vars qw(@ISA $VERSION);
+use DynaLoader;
 
-our $VERSION;
 BEGIN {
-	$VERSION = '4.19_9903';
-	XSLoader::load(__PACKAGE__, $VERSION);
-}
-
-END {
-    _global_cleanup();
-}
-
-our $AUTOLOAD;
-sub AUTOLOAD {
-    (my $constname = $AUTOLOAD) =~ s/.*:://;
-    die "&WWW::Curl::constant not defined" if $constname eq 'constant';
-    my ($error, $val) = constant($constname);
-    if ($error) {
-        my (undef,$file,$line) = caller;
-        die "$error at $file line $line.\n";
-    }
-    no strict 'refs';
-    *$AUTOLOAD = sub { $val };
-    goto &$AUTOLOAD;
+    $VERSION = '4.01';
+    @ISA     = qw(DynaLoader);
+    __PACKAGE__->bootstrap;
 }
 
 1;
@@ -64,14 +46,19 @@ Here is a small snippet of making a request with WWW::Curl::Easy.
 	use warnings;
 	use WWW::Curl::Easy;
 
-	my $curl = WWW::Curl::Easy->new;
+	# Setting the options
+	my $curl = new WWW::Curl::Easy;
 	
+	# Redirecting the default STDOUT target for header contents, to
+	# an anonymous temporary file
+	open(my $fileh, '+>', undef);
+	$curl->setopt(CURLOPT_HEADERDATA,$fileh);
+
 	$curl->setopt(CURLOPT_HEADER,1);
 	$curl->setopt(CURLOPT_URL, 'http://example.com');
-
-	# A filehandle, reference to a scalar or reference to a typeglob can be used here.
 	my $response_body;
-	$curl->setopt(CURLOPT_WRITEDATA,\$response_body);
+	open (my $fileb, ">", \$response_body);
+	$curl->setopt(CURLOPT_WRITEDATA,$fileb);
 
 	# Starts the actual request
 	my $retcode = $curl->perform;
@@ -83,11 +70,9 @@ Here is a small snippet of making a request with WWW::Curl::Easy.
 		# judge result and next action based on $response_code
 		print("Received response: $response_body\n");
 	} else {
-		# Error code, type of error, error message
-		print("An error happened: $retcode ".$curl->strerror($retcode)." ".$curl->errbuf."\n");
+		print("An error happened: ".$curl->strerror($retcode)." ($retcode)\n");
 	}
 
-See L<curl_easy_setopt(3)> for details of C<setopt()>.
 
 =head1 WWW::Curl::Multi
 
@@ -97,7 +82,7 @@ See L<curl_easy_setopt(3)> for details of C<setopt()>.
 	use WWW::Curl::Multi;
 
 	my %easy;
-	my $curl = WWW::Curl::Easy->new;
+	my $curl = WWW::Curl::Easy->new:
 	my $curl_id = '13'; # This should be a handle unique id.
 	$easy{$curl_id} = $curl;
 	my $active_handles = 0;
@@ -113,12 +98,6 @@ See L<curl_easy_setopt(3)> for details of C<setopt()>.
 	$active_handles++;
 
 	while ($active_handles) {
-		my $timeout = $curlm->timeout();
-		if ( $timeout > 1 ) {
-			my ($rv, $wv, $ev) = $curlm->fdset_vec;
-			select $rv, $wv, $ev, $timeout / 1000;
-		}
-
 		my $active_transfers = $curlm->perform;
 		if ($active_transfers != $active_handles) {
 			while (my ($id,$return_value) = $curlm->info_read) {
@@ -188,26 +167,6 @@ This is how you enable sharing for a specific WWW::Curl::Easy handle:
 	$curl->setopt(CURLOPT_SHARE, $curlsh)
 		Attach share object to WWW::Curl::Easy instance
 
-=head1 WWW::Curl::Form
-
-    use WWW::Curl::Form;
-    my $curlf = WWW::Curl::Form->new;
-    $curlf->formaddfile($filename, 'attachment', "multipart/form-data");
-    $curlf->formadd("FIELDNAME", "VALUE");
-
-    $curl->setopt(CURLOPT_HTTPPOST, $curlf);
-
-Its usable methods are:
-
-    $curlf = new WWW::Curl::Form
-        This method constructs a new WWW::Curl::Form object.
-
-    $curlf->formadd(FIELDNAME, VALUE)
-        This method adds a field with a given value, to the form that is being submitted.
-
-    $curlf->formaddfile(FILENAME, DESCRIPTION, TYPE)
-        This method will add a file to the form. The description is the name of the field
-        that you form expects the data to be submitted in.
 
 =head1 COMPATIBILITY
 
@@ -256,16 +215,12 @@ Not implemented and won't be as this method is considered deprecated.
 
 =item curl_formadd
 
-Seems to be working.
-
-=item curl_formaddfile
-
-Seems to be working.
+Not yet implemented.
 
 =item curl_formfree
 
-Used internally. Not exposed through the public API, as this call has no relevance
-to Perl code.
+When WWW::Curl::Form support is added, this function will be used internally,
+but won't be accessible from the public API.
 
 =item curl_free
 
@@ -289,10 +244,6 @@ Only used internally, not exposed through the public API.
 
 Not implemented.
 
-=item curl_global_cleanup
-
-Only used internally and called automatically upon exit.
-
 =item curl_slist_append
 
 Only used internally, not exposed through the public API.
@@ -305,10 +256,6 @@ Only used internally, not exposed through the public API.
 
 Not implemented and won't be, as this method is considered deprecated.
 
-=item curl_version
-
-Seems to work.
-
 =item curl_version_info
 
 Not yet implemented.
@@ -318,63 +265,23 @@ Not yet implemented.
 Most methods are either not exposed through the WWW::Curl::Multi API or they behave differently
 than it's C counterpart. Please see the section about WWW::Curl::Multi above.
 
-=item curl_multi_fdset
-
-This method returns three arrayrefs: the read, write and exception fds libcurl knows about.
-In the case of no file descriptors in the given set, an empty array is returned.
-
-=item constant
-
-Useless.
-
-=back
-
-=head1 NUANCES
-
-=head2 Header output for redirects
-
-It might be surprising that if C<CURLOPT_FOLLOWLOCATION> is set and header output was enabled, headers show up for all http responses.
-The reasoning behind that and possible code adjustments are outlined here: L<https://rt.cpan.org/Ticket/Display.html?id=61569>.
-
-=head2 CURLOPT_PRIVATE
-
-Despite what the libcurl manual says, in Perl land, only string values are suitable for this option.
-
-=head1 ADDITIONAL METHODS
-
-=head2 On WWW::Curl::Easy objects
-
-=over 
-
-=item pushopt
-
-Like C<setopt> but instead of overriding any previously set values it adds it 
-to the end. Can be used with C<CURLOPT_HTTPHEADER>, C<CURLOPT_QUOTE> and 
-C<CURLOPT_POSTQUOTE>.
-
-
 =back
 
 =head1 USAGE CASES
 
-WWW::Curl is a thin binding on top of libcurl, to make using libcurl possible from Perl land.
-Because of this, the module is less like Perl and more like C in coding style.
-
-There is a new module, L<http://search.cpan.org/perldoc?WWW::Curl::Simple>,
-which wraps this module into a more Perlish and userfriendly package.
-
-The standard Perl WWW module, LWP should probably be used in most cases to work with HTTP or FTP from Perl.
-However, there are some cases where LWP doesn't perform well. One is speed and the other is parallelism. 
-WWW::Curl is much faster, uses much less CPU cycles and it's capable of non-blocking parallel requests.
+The standard Perl WWW module, LWP should be used in most cases to work with
+the HTTP or FTP protocol from Perl. However, there are some cases where LWP doesn't
+perform well. One is speed and the other is paralellism. WWW::Curl is much faster,
+uses much less CPU cycles and it's capable of non-blocking parallel requests.
 
 In some cases, for example when building a web crawler, cpu usage and parallel downloads are
 important considerations. It can be desirable to use WWW::Curl to do the heavy-lifting of
 a large number of downloads and wrap the resulting data into a Perl-friendly structure by
-HTTP::Response or use WWW::Curl::Simple to do that for you.
+HTTP::Response.
 
 =head1 CHANGES
 
-Version 4.01 - 4.07 adds several bugfixes and extends functionality coverage. See Changes file.
+Version 4.01 adds several bugfixes. See Changes file.
 
 Version 4.00 added new documentation, the build system changed to Module::Install,
 the test suite was rewritten to use Test::More, a new calling syntax for WWW::Curl::Multi
@@ -393,7 +300,7 @@ Version 3.02 adds some backwards compatibility for scripts still using
 
 Version 3.01 added some support for pre-multi versions of libcurl.
 
-Version 3.00 adds WWW::Curl::Multi interface, and new module names
+Version 3.00 adds WWW::Curl::Multi interface, and a new module names
 following perl conventions (WWW::Curl::Easy rather than WWW::Curl::easy),
 by Sebastian Riedel <sri at cpan.org>.
 
@@ -406,8 +313,7 @@ reworked from the previous Curl::easy release (1.21) by Cris Bailiff.
 
 =head1 AUTHORS
 
-Currently maintained by Cris Bailiff <c.bailiff+curl at devsecure.com> and
-Balint Szilakszi <szbalint at cpan.org>.
+Currently maintained by Cris Bailiff <c.bailiff+curl at devsecure.com>
 
 Original Author Georg Horn <horn@koblenz-net.de>, with additional callback,
 pod and test work by Cris Bailiff <c.bailiff+curl@devsecure.com> and
@@ -417,9 +323,9 @@ repackaged the module into a more modern form.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000-2005,2008-2010 Daniel Stenberg, Cris Bailiff,
+Copyright (C) 2000-2005,2008 Daniel Stenberg, Cris Bailiff,
 Sebastian Riedel, Balint Szilakszi et al.
-
+ 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
 to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
@@ -427,10 +333,4 @@ pick one of these licenses.
 
 =head1 SEE ALSO
 
-L<http://curl.haxx.se>
-
-L<http://search.cpan.org/perldoc?WWW::Curl::Simple>
-
-L<libcurl(3)>
-
-The development source code is also available: L<http://github.com/szbalint/WWW--Curl/tree/master>
+http://curl.haxx.se
